@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -443,7 +443,7 @@ parse_key_value (AnjutaPluginDescriptionParser *parser, GError **error)
   gchar *key_end;
   gchar *key;
   gchar *locale_start = NULL;
-  gchar *locale_end;
+  gchar *locale_end = NULL;
   gchar *value_start;
   gchar *value;
   gchar *p;
