@@ -3,10 +3,12 @@
 
 #include "ianjuta-bookmark.h"
 #include "ianjuta-buildable.h"
-#include "ianjuta-cpu-debugger.h"
 #include "ianjuta-debug-manager.h"
 #include "ianjuta-debugger.h"
 #include "ianjuta-debugger-breakpoint.h"
+#include "ianjuta-debugger-instruction.h"
+#include "ianjuta-debugger-memory.h"
+#include "ianjuta-debugger-register.h"
 #include "ianjuta-debugger-variable.h"
 #include "ianjuta-document.h"
 #include "ianjuta-document-manager.h"
