@@ -434,10 +434,6 @@ cpp_java_assist_get_calltip_context (CppJavaAssist *assist,
 	gchar ch;
 	gchar *context = NULL;
 	
-#ifdef DEBUG
-	GTimer* timer = g_timer_new ();
-#endif
-	
 	ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter), 0, NULL);
 	if (ch == ')')
 	{
@@ -445,14 +441,12 @@ cpp_java_assist_get_calltip_context (CppJavaAssist *assist,
 			return NULL;
 		if (!ianjuta_iterable_previous (iter, NULL))
 			return NULL;
-		//DEBUG_PRINT ("calltip ')' brace: %f", g_timer_elapsed (timer, NULL));
 	}
 	if (ch != '(')
 	{
 		if (!cpp_java_util_jump_to_matching_brace (iter, ')',
 												   BRACE_SEARCH_LIMIT))
 			return NULL;
-		//DEBUG_PRINT ("calltip ')' brace: %f", g_timer_elapsed (timer, NULL));
 	}
 	
 	/* Skip white spaces */
@@ -460,22 +454,14 @@ cpp_java_assist_get_calltip_context (CppJavaAssist *assist,
 		&& g_ascii_isspace (ianjuta_editor_cell_get_char
 								(IANJUTA_EDITOR_CELL (iter), 0, NULL)));
 
-	//DEBUG_PRINT ("calltip skip whitespace: %f", g_timer_elapsed (timer, NULL));
 	
 	context = cpp_java_assist_get_scope_context
 		(IANJUTA_EDITOR (assist->priv->iassist), "(", iter);
 	
-	//DEBUG_PRINT ("calltip get scope context: %f", g_timer_elapsed (timer, NULL));
-	
 	if (context_offset)
 	{
 		*context_offset = get_iter_column (assist, iter);
-		//DEBUG_PRINT ("calltip get iter column: %f", g_timer_elapsed (timer, NULL));
 	}
-
-#ifdef DEBUG
-	g_timer_destroy (timer);
-#endif
 	
 	return context;
 }
@@ -561,9 +547,6 @@ cpp_java_assist_check (CppJavaAssist *assist, gboolean autocomplete,
 	IAnjutaIterable *iter, *iter_save;
 	IAnjutaEditorAttribute attribute;
 	gchar *pre_word = NULL, *scope_operator = NULL;
-#ifdef DEBUG
-	GTimer* timer = g_timer_new();
-#endif
 	
 	//DEBUG_PRINT ("Autocomplete enable is: %d", autocomplete);
 	//DEBUG_PRINT ("Calltips enable is: %d", calltips);
@@ -609,7 +592,6 @@ cpp_java_assist_check (CppJavaAssist *assist, gboolean autocomplete,
 															   scope_operator,
 															   iter);
 			
-			DEBUG_PRINT ("assist scope context: %f", g_timer_elapsed (timer, NULL));
 			DEBUG_PRINT ("Scope context: %s", scope_context);
 			
 			if (scope_context)
@@ -643,9 +625,6 @@ cpp_java_assist_check (CppJavaAssist *assist, gboolean autocomplete,
 		}
 		//DEBUG_PRINT ("assist autocomplete: %f", g_timer_elapsed (timer, NULL));
 	}
-#ifdef DEBUG
-	g_timer_reset (timer);
-#endif
 	if (calltips)
 	{
 		if (!shown)
@@ -671,10 +650,6 @@ cpp_java_assist_check (CppJavaAssist *assist, gboolean autocomplete,
 	g_object_unref (iter_save);
 	g_free (pre_word);
 	g_free (scope_operator);
-#ifdef DEBUG
-	g_timer_stop (timer);
-	g_timer_destroy (timer);
-#endif
 	return shown;
 }
 
