@@ -336,6 +336,7 @@ on_svn_notify (gpointer baton,
 			break;
 		case svn_wc_notify_resolved:
 			action_message = g_strdup_printf (_("Resolved: %s"), notify->path);
+			break;
 		case svn_wc_notify_update_delete:
 			action_message = g_strdup_printf (_("Deleted: %s"), notify->path);
 			break;
@@ -598,6 +599,16 @@ svn_command_unlock_ui (SvnCommand *self)
 	g_mutex_unlock (self->priv->ui_lock);
 }
 
+gchar *
+svn_command_make_canonical_path (SvnCommand *self, gchar *path)
+{
+	const gchar *canonical_path;
+	
+	canonical_path = svn_path_canonicalize (path, self->priv->pool);
+	
+	return g_strdup (canonical_path);
+}
+
 svn_opt_revision_t *
 svn_command_get_revision (gchar *revision)
 {
